// noinspection JSJQueryEfficiency

/**
 * @file
 * Js for Glossary Content.
 */

(($, Drupal, once) => {
  const tLoading = Drupal.t('Loading...');
  // Allow dialog title translation.
  const tTermDefinition = Drupal.t('Term definition');
  function onTermActivation(event) {
    event.preventDefault();
    const termId = event.currentTarget.dataset.gterm;
    const termText = event.currentTarget.textContent;
    const $dialog = $(document.getElementById('glossary-dialog'));
    const dialog = $dialog.dialog({
      autoOpen: true,
      resizable: false,
      modal: true,
      // Allow default close label translation.
      closeText: Drupal.t('Close'),
      close() {
        $dialog
          .find('#glossary-dialog-inner')
          .html(
            `<div class="ajax-progress ajax-progress-throbber"><div class="ajax-throbber">${tLoading}</div></div>`,
          );
      },
      buttons: [
        {
          // Allow close button label translation.
          text: Drupal.t('Close'),
          click(evt) {
            evt.preventDefault();
            dialog.dialog('close');
          },
          // WCAG: handle keypress event.
          keypress(evt) {
            // Needed to avoid the click event being fired next.
            evt.preventDefault();
            dialog.dialog('close');
          },
        },
      ],
    });
    // Call Ajax here.
    const url = Drupal.url(`glossary-get-term-by-id/${termId}`);
    $.ajax({
      url,
      dataType: 'json',
      type: 'GET',
      success(data) {
        const $dialogInner = $dialog.find('#glossary-dialog-inner');
        if (data.html) {
          $dialogInner.html(data.html);
          $dialogInner.removeClass('hidden');
          /* $dialog.parent().position({
            my: 'center',
            at: 'center',
            of: window,
          }); */
          const showEvent = new CustomEvent('glossary_modal_show', {
            detail: data,
          });
          document.dispatchEvent(showEvent);
        } else {
          // Allow "no results" message translation.
          const tNoResultsFound = Drupal.t('No results found for @term', {
            '@term': termText,
          });
          $dialogInner.html(tNoResultsFound);
        }
      },
    });
  }
  Drupal.behaviors.GlossaryContent = {
    attach(context) {
      once('glossary-init-dialog', 'body', context).forEach((body) => {
        body.insertAdjacentHTML(
          'beforeend',
          `<div id="glossary-dialog" class="hidden" title="${tTermDefinition}"><div id="glossary-dialog-inner"><div class="ajax-progress ajax-progress-throbber"><div class="ajax-throbber">${tLoading}</div></div></div></div>`,
        );
      });
      once('glossaryListener', '.glos-term', context).forEach((term) => {
        term.addEventListener('click', onTermActivation);
        // WCAG: handle keypress event.
        term.addEventListener('keypress', onTermActivation);
      });
    },
  };
})(jQuery, Drupal, once);
